[llvm-commits] [llvm] r74023 - in /llvm/trunk/include/llvm/MC: MCImm.h MCInst.h MCValue.h

Chris Lattner sabre at nondot.org
Tue Jun 23 16:31:52 PDT 2009


Author: lattner
Date: Tue Jun 23 18:31:52 2009
New Revision: 74023

URL: http://llvm.org/viewvc/llvm-project?rev=74023&view=rev
Log:
rename MCImm ->MCValue.

Added:
    llvm/trunk/include/llvm/MC/MCValue.h
      - copied, changed from r74018, llvm/trunk/include/llvm/MC/MCImm.h
Removed:
    llvm/trunk/include/llvm/MC/MCImm.h
Modified:
    llvm/trunk/include/llvm/MC/MCInst.h

Removed: llvm/trunk/include/llvm/MC/MCImm.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/MC/MCImm.h?rev=74022&view=auto

==============================================================================
--- llvm/trunk/include/llvm/MC/MCImm.h (original)
+++ llvm/trunk/include/llvm/MC/MCImm.h (removed)
@@ -1,57 +0,0 @@
-//===-- llvm/MC/MCImm.h - MCImm class ---------------------------*- C++ -*-===//
-//
-//                     The LLVM Compiler Infrastructure
-//
-// This file is distributed under the University of Illinois Open Source
-// License. See LICENSE.TXT for details.
-//
-//===----------------------------------------------------------------------===//
-//
-// This file contains the declaration of the MCInst and MCOperand classes, which
-// is the basic representation used to represent low-level machine code
-// instructions.
-//
-//===----------------------------------------------------------------------===//
-
-#ifndef LLVM_MC_MCIMM_H
-#define LLVM_MC_MCIMM_H
-
-#include "llvm/Support/DataTypes.h"
-
-namespace llvm {
-class MCSymbol;
-
-/// MCImm - This represents an "assembler immediate".  In its most general form,
-/// this can hold "SymbolA - SymbolB + imm64".  Not all targets supports
-/// relocations of this general form, but we need to represent this anyway.
-class MCImm {
-  MCSymbol *SymA, *SymB;
-  int64_t Cst;
-public:
-
-  int64_t getCst() const { return Cst; }
-  MCSymbol *getSymA() const { return SymA; }
-  MCSymbol *getSymB() const { return SymB; }
-  
-  
-  static MCImm get(MCSymbol *SymA, MCSymbol *SymB = 0, int64_t Val = 0) {
-    MCImm R;
-    R.Cst = Val;
-    R.SymA = SymA;
-    R.SymB = SymB;
-    return R;
-  }
-  
-  static MCImm get(int64_t Val) {
-    MCImm R;
-    R.Cst = Val;
-    R.SymA = 0;
-    R.SymB = 0;
-    return R;
-  }
-  
-};
-
-} // end namespace llvm
-
-#endif

Modified: llvm/trunk/include/llvm/MC/MCInst.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/MC/MCInst.h?rev=74023&r1=74022&r2=74023&view=diff

==============================================================================
--- llvm/trunk/include/llvm/MC/MCInst.h (original)
+++ llvm/trunk/include/llvm/MC/MCInst.h Tue Jun 23 18:31:52 2009
@@ -16,7 +16,7 @@
 #ifndef LLVM_MC_MCINST_H
 #define LLVM_MC_MCINST_H
 
-#include "llvm/MC/MCImm.h"
+#include "llvm/MC/MCValue.h"
 #include "llvm/ADT/SmallVector.h"
 #include "llvm/Support/DataTypes.h"
 #include "llvm/Support/DebugLoc.h"
@@ -31,14 +31,14 @@
     kRegister,                ///< Register operand.
     kImmediate,               ///< Immediate operand.
     kMBBLabel,                ///< Basic block label.
-    kMCImm
+    kMCValue
   };
   unsigned char Kind;
   
   union {
     unsigned RegVal;
     int64_t ImmVal;
-    MCImm MCImmVal;
+    MCValue MCValueVal;
     struct {
       unsigned FunctionNo;
       unsigned BlockNo;

Copied: llvm/trunk/include/llvm/MC/MCValue.h (from r74018, llvm/trunk/include/llvm/MC/MCImm.h)
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/MC/MCValue.h?p2=llvm/trunk/include/llvm/MC/MCValue.h&p1=llvm/trunk/include/llvm/MC/MCImm.h&r1=74018&r2=74023&rev=74023&view=diff

==============================================================================
--- llvm/trunk/include/llvm/MC/MCImm.h (original)
+++ llvm/trunk/include/llvm/MC/MCValue.h Tue Jun 23 18:31:52 2009
@@ -1,4 +1,4 @@
-//===-- llvm/MC/MCImm.h - MCImm class ---------------------------*- C++ -*-===//
+//===-- llvm/MC/MCValue.h - MCValue class -----------------------*- C++ -*-===//
 //
 //                     The LLVM Compiler Infrastructure
 //
@@ -7,24 +7,25 @@
 //
 //===----------------------------------------------------------------------===//
 //
-// This file contains the declaration of the MCInst and MCOperand classes, which
-// is the basic representation used to represent low-level machine code
-// instructions.
+// This file contains the declaration of the MCValue class.
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_MC_MCIMM_H
-#define LLVM_MC_MCIMM_H
+#ifndef LLVM_MC_MCVALUE_H
+#define LLVM_MC_MCVALUE_H
 
 #include "llvm/Support/DataTypes.h"
 
 namespace llvm {
 class MCSymbol;
 
 /// MCImm - This represents an "assembler immediate".  In its most general form,
 /// this can hold "SymbolA - SymbolB + imm64".  Not all targets supports
 /// relocations of this general form, but we need to represent this anyway.
-class MCImm {
+///
+/// Note that this class must remain a simple POD value class, because we need
+/// it to live in unions etc.
+class MCValue {
   MCSymbol *SymA, *SymB;
   int64_t Cst;
 public:
@@ -34,16 +35,16 @@
   MCSymbol *getSymB() const { return SymB; }
   
   
-  static MCImm get(MCSymbol *SymA, MCSymbol *SymB = 0, int64_t Val = 0) {
-    MCImm R;
+  static MCValue get(MCSymbol *SymA, MCSymbol *SymB = 0, int64_t Val = 0) {
+    MCValue R;
     R.Cst = Val;
     R.SymA = SymA;
     R.SymB = SymB;
     return R;
   }
   
-  static MCImm get(int64_t Val) {
-    MCImm R;
+  static MCValue get(int64_t Val) {
+    MCValue R;
     R.Cst = Val;
     R.SymA = 0;
     R.SymB = 0;
@@ -7,24 +7,25 @@
 class MCSymbol;
 
-/// MCImm - This represents an "assembler immediate".  In its most general form,
-/// this can hold "SymbolA - SymbolB + imm64".  Not all targets supports
+/// MCValue - This represents an "assembler immediate".  In its most general
+/// form, this can hold "SymbolA - SymbolB + imm64".  Not all targets supports
 /// relocations of this general form, but we need to represent this anyway.





More information about the llvm-commits mailing list